@@ -62,7 +62,7 @@ on_main_window_delete_event(
 
 
   gboolean
-on_scope_draw(
+on_scope_drawingarea_draw(
 	GtkWidget *widget,
 	cairo_t   *cr,
 	gpointer  user_data)
@@ -71,13 +71,72 @@ on_scope_draw(
   return( TRUE );
 }
 
+  void
+on_receiver_combobox_changed(
+	GtkComboBox     *combobox,
+    gpointer         user_data)
+{
+  GtkWidget *toggle = Builder_Get_Object( main_builder, "receive_togglebutton" );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(toggle), FALSE );
+
+  gchar *txt = gtk_combo_box_text_get_active_text( receiver_combobox );
+  if( strcmp(txt, "FT847") == 0 )
+	rc_data.receiver_type = FT847;
+  else if( strcmp(txt, "FT857") == 0 )
+	rc_data.receiver_type = FT857;
+  else if( strcmp(txt, "K2") == 0 )
+	rc_data.receiver_type = K2;
+  else if( strcmp(txt, "K3") == 0 )
+	rc_data.receiver_type = K3;
+  else if( strcmp(txt, "PERSEUS") == 0 )
+	rc_data.receiver_type = PERSEUS;
+  else if( strcmp(txt, "-- NONE --") == 0 )
+	rc_data.receiver_type = NONE;
+
+  if( rc_data.receiver_type == PERSEUS )
+	rc_data.open_type = SND_OPEN_PLAYBACK;
+  else
+	rc_data.open_type = SND_OPEN_CAPTURE;
+
+  /* Enable Transceiver CAT */
+  if( rc_data.receiver_type == NONE )
+	Clear_Flag( ENABLE_CAT );
+  else
+	Set_Flag( ENABLE_CAT );
+}
+
 
   void
-on_speed_changed(
-	GtkEditable *editable,
-	gpointer     user_data)
+on_frequency_spinbutton_value_changed(
+	GtkSpinButton *spin_button,
+	gpointer       user_data)
 {
-  rc_data.unit_elem = gtk_spin_button_get_value_as_int( speed );
+  rc_data.receiver_freq = gtk_spin_button_get_value_as_int( spin_button );
+  Write_Rx_Freq( rc_data.receiver_freq );
+}
+
+
+  gboolean
+on_frequency_spinbutton_scroll_event(
+	GtkWidget *widget,
+	GdkEvent  *event,
+	gpointer   user_data)
+{
+  if( event->scroll.direction == GDK_SCROLL_UP )
+	rc_data.receiver_freq++;
+  else if( event->scroll.direction == GDK_SCROLL_DOWN )
+	rc_data.receiver_freq--;
+  gtk_spin_button_set_value( frequency, (double)rc_data.receiver_freq );
+  return( TRUE );
+}
+
+
+  void
+on_wpm_spinbutton_value_changed(
+	GtkSpinButton *spin_button,
+	gpointer       user_data)
+{
+  rc_data.unit_elem = gtk_spin_button_get_value_as_int( spin_button );
   rc_data.unit_elem =
 	(60 * rc_data.tone_freq) /
 	(50 * CYCLES_PER_FRAG * rc_data.unit_elem);
@@ -85,27 +144,27 @@ on_speed_changed(
 
 
   void
-on_squelch_changed(
-	GtkEditable *editable,
-	gpointer     user_data)
+on_squelch_spinbutton_value_changed(
+	GtkSpinButton *spin_button,
+	gpointer       user_data)
 {
   rc_data.det_squelch =
-	gtk_spin_button_get_value_as_int( squelch );
+	gtk_spin_button_get_value_as_int( spin_button );
 }
 
 
   void
-on_ratio_changed(
-	GtkEditable *editable,
-	gpointer     user_data)
+on_ratio_spinbutton_value_changed(
+	GtkSpinButton *spin_button,
+	gpointer       user_data)
 {
   rc_data.det_ratio =
-	gtk_spin_button_get_value( ratio );
+	gtk_spin_button_get_value( spin_button );
 }
 
 
   void
-on_err_quit_clicked(
+on_error_quit_button_clicked(
 	GtkButton *button,
 	gpointer   user_data)
 {
@@ -115,7 +174,7 @@ on_err_quit_clicked(
 
 
   void
-on_clearwin_clicked(
+on_clear_button_clicked(
 	GtkButton *button,
 	gpointer   user_data)
 {
@@ -124,7 +183,7 @@ on_clearwin_clicked(
 
 
   gboolean
-on_waterfall_draw(
+on_waterfall_drawingarea_draw(
 	GtkWidget *widget,
 	cairo_t   *cr,
 	gpointer   user_data)
@@ -139,7 +198,7 @@ on_waterfall_draw(
 
 
   gboolean
-on_waterfall_button_press_event(
+on_waterfall_drawingarea_button_press_event(
 	GtkWidget      *widget,
 	GdkEventButton *event,
 	gpointer        user_data)
@@ -154,7 +213,7 @@ on_waterfall_button_press_event(
 
 
   void
-on_err_ok_button_clicked(
+on_error_ok_button_clicked(
 	GtkButton *button,
 	gpointer   user_data)
 {
@@ -163,7 +222,7 @@ on_err_ok_button_clicked(
 
 
   void
-on_wpm_toggled(
+on_auto_checkbutton_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
 {
@@ -194,7 +253,7 @@ on_error_dialog_delete_event(
 
 
   void
-on_waterfall_configure_event(
+on_waterfall_drawingarea_configure_event(
 	GtkWidget    *widget,
 	GdkEventConfigure *event,
 	gpointer     user_data )
@@ -204,7 +263,7 @@ on_waterfall_configure_event(
 
 
   void
-on_receive_toggled(
+on_receive_togglebutton_toggled(
 	GtkToggleButton *togglebutton,
 	gpointer         user_data)
 {
@@ -226,35 +285,43 @@ on_receive_toggled(
 	  Cleanup();
 	  Error_Dialog( mesg );
 	}
-	else if( isFlagSet(ENABLE_RECEIVE) )
+	else if( isFlagSet(ENABLE_RECEIVE) ) /* Detector initialiazed OK */
 	{
-	  if( isFlagSet(ENABLE_CAT) ) Open_Tcvr_Serial();
+	  if( isFlagSet(ENABLE_CAT) ) /* Valid receiver specified */
+	  {
+#ifdef HAVE_LIBPERSEUS_SDR
+		if( rc_data.receiver_type == PERSEUS )
+		{
+		  if( !Perseus_Initialize() ) return;
+		}
+		else
+#endif
+		  Open_Tcvr_Serial();
+	  }
+
+	  /* Start receiving and decoding signals */
 	  g_idle_add( Print_Character, "RX" );
 	}
 	else
 	  Error_Dialog( _("Failed to initialize signal detector") );
-  }
+  } /* if( gtk_toggle_button_get_active(togglebutton) */
   else
   {
 	if( isFlagSet(ENABLE_RECEIVE) )
 	{
 	  g_idle_remove_by_data( "RX" );
-	  if( isFlagSet(ENABLE_CAT) ) Close_Tcvr_Serial();
-	  Close_Capture_Handle();
-	}
-  }
-}
 
+#ifdef HAVE_LIBPERSEUS_SDR
+	  if( rc_data.receiver_type == PERSEUS )
+		Perseus_Close_Device();
+	  else
+#endif
+		if( isFlagSet(ENABLE_CAT) )
+		  Close_Tcvr_Serial();
 
-  void
-on_centerline_checkbutton_toggled(
-	GtkToggleButton *togglebutton,
-	gpointer         user_data)
-{
-  if( gtk_toggle_button_get_active(togglebutton) )
-	Set_Flag( CENTERLINE );
-  else
-	Clear_Flag( CENTERLINE );
+	  Close_PCM_Handle();
+	} /* if( isFlagSet(ENABLE_RECEIVE) ) */
+  } /* else of if( gtk_toggle_button_get_active(togglebutton) */
 }
 
 
