@@ -16,7 +16,7 @@
 #define CAT_H	1
 
 #include "common.h"
-#include "dft.h"
+#include "ifft.h"
 #include <termios.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
@@ -28,12 +28,13 @@ enum
   FT847,
   FT857,
   K2,
-  K3
+  K3,
+  PERSEUS
 };
 
 #define MAX_SERIAL_RETRIES	10
 
-/* Range (+/-) in pixels to look for DFT maximum
+/* Range (+/-) in pixels to look for IFFT maximum
  * when click-to-tune on waterfall by user */
 #define CLICK_TUNE_RANGE	20
 
