@@ -15,9 +15,9 @@
 #ifndef DETECT_H
 #define DETECT_H	1
 
-#include <math.h>
 #include "common.h"
 #include "display.h"
+#include "cat.h"
 
 /* Minimum level of lead+trail edge of tone over
  * which the tone detector looks for mark or space */
