@@ -18,20 +18,24 @@
 
 /*------------------------------------------------------------------------*/
 
-/* DFT_Bin_Value()
+/* IFFT_Bin_Value()
  *
- * Calculates DFT bin values with auto level control
+ * Calculates IFFT bin values with auto level control
  */
   static int
-DFT_Bin_Value( int sum_i, int sum_q, gboolean reset )
+IFFT_Bin_Value( int sum_i, int sum_q, gboolean reset )
 {
- /* Value of dft output "bin" */
+ /* Value of ifft output "bin" */
   static int bin_val = 0;
 
-  /* Maximum value of dft bins */
+  /* Maximum value of ifft bins */
   static int bin_max = 1000, max = 0;
 
 
+  /* Scale output from IFFT */
+  sum_i /= IFFT_SCALE;
+  sum_q /= IFFT_SCALE;
+
   /* Calculate sliding window average of max bin value */
   if( reset )
   {
@@ -56,7 +60,7 @@ DFT_Bin_Value( int sum_i, int sum_q, gboolean reset )
   }
 
   return( 0 );
-} /* DFT_Bin_Value() */
+} /* IFFT_Bin_Value() */
 
 /*------------------------------------------------------------------------*/
 
@@ -142,9 +146,11 @@ Display_Signal( cairo_t *cr, GdkPoint *points )
 Display_Waterfall( void )
 {
   int
-	idh, idv,  /* Index to hor. and vert. position in warterfall */
-	pixel_val, /* Greyscale value of pixel derived from dft o/p  */
-	dft_idx;   /* Index to dft output array */
+	idh, idv,	/* Index to hor. and vert. position in warterfall */
+	pixel_val,	/* Greyscale value of pixel derived from ifft o/p  */
+	idf,		/* Index to ifft output array */
+	idb,		/* Index to average bin values array */
+	temp;
 
   /* Constant needed to draw center line in waterfall */
   int center_line = wfall_width / 2;
@@ -152,16 +158,15 @@ Display_Waterfall( void )
   /* Pointer to current pixel */
   static guchar *pix;
 
+
   /* Draw a vertical white line in waterfall at detector's freq. */
-  if( isFlagSet(CENTERLINE) )
-  {
-	pix = wfall_pixels + wfall_rowstride + wfall_n_channels;
-	pix += wfall_n_channels * center_line;
-	pix[0] = pix[1] = pix[2] = 0xff;
-  }
+  pix    = wfall_pixels + wfall_rowstride + wfall_n_channels;
+  pix   += wfall_n_channels * center_line;
+  pix[0] = pix[1] = pix[2] = 0xff;
 
   /* Copy each line of waterfall to next one */
-  for( idv = wfall_height-2; idv > 0; idv-- )
+  temp = wfall_height - 2;
+  for( idv = temp; idv > 0; idv-- )
   {
 	pix = wfall_pixels + wfall_rowstride * idv + wfall_n_channels;
 
@@ -180,16 +185,17 @@ Display_Waterfall( void )
   /* First column of display (DC) not used */
   bin_ave[0] = 0;
 
-  /* Do the DFT on input array */
-  Idft( DFT_INPUT_SIZE, wfall_width );
-  for( dft_idx = 0; dft_idx < wfall_width; dft_idx++ )
+  /* Do the IFFT on input array */
+  IFFT_Real( ifft_data );
+  idb = 0;
+  for( idf = 2; idf < ifft_data_length; idf += 2 )
   {
 	/* Calculate signal power at each frequency (bin) */
-	dft_out_r[dft_idx] /= 1024;
-	dft_out_i[dft_idx] /= 1024;
-	pixel_val = DFT_Bin_Value(
-		dft_out_r[dft_idx], dft_out_i[dft_idx], FALSE );
-	bin_ave[dft_idx] = pixel_val;
+	pixel_val = IFFT_Bin_Value(
+		ifft_data[idf], ifft_data[idf + 1], FALSE );
+
+	/* Calculate average bin values */
+	bin_ave[idb++] = pixel_val;
 
 	/* Color code signal strength */
 	int n;
@@ -199,27 +205,27 @@ Display_Waterfall( void )
 	  pix[1] = 0;
 	  pix[2] = 3 + (guchar)pixel_val * 3;
 	}
-	else if( pixel_val < 170 )
+	else if( pixel_val <= 170 )
 	{
 	  n = pixel_val - 85;
 	  pix[0] = 0;
-	  pix[1] = 3 + (guchar)n * 3;
+	  pix[1] = (guchar)n * 3;
 	  pix[2] = 255 - (guchar)n * 3;
 	}
 	else
 	{
-	  n = pixel_val - 170;
-	  pix[0] = (guchar)pixel_val;
+	  n = pixel_val - 171;
+	  pix[0] = 3 + (guchar)n * 3;
 	  pix[1] = 255;
 	  pix[2] = 0;
 	}
 
 	pix += wfall_n_channels;
 
-  } /* for( dft_idx = 0; dft_idx < dft_end; dft_idx++ ) */
+  } /* for( idf = 2; idf < ifft_data_length; idf += 2 ) */
 
   /* Reset function */
-  pixel_val = DFT_Bin_Value( 0, 0, TRUE );
+  IFFT_Bin_Value( 0, 0, TRUE );
 
   /* At last draw waterfall */
   gtk_widget_queue_draw( waterfall );
