@@ -26,8 +26,12 @@ extern GtkWidget
   *waterfall,
   *scope_label;
 
+/* Receiver type combobox */
+extern GtkComboBoxText *receiver_combobox;
+
 /* Speed and squelch spin button */
 extern GtkSpinButton
+  *frequency,
   *speed,
   *squelch,
   *ratio;
@@ -60,11 +64,20 @@ extern gint
 /* Average bin values */
 extern int *bin_ave;
 
-/* dft in/out buffers */
-extern int
-  *dft_in_r,
-  *dft_out_r,
-  *dft_out_i;
+/* ifft in/out buffers */
+extern int16_t
+  *ifft_data,
+  ifft_data_length;
+
+extern sem_t pback_semaphore;
+
+/* Sound Playback Buffer has to be a ring
+ * buffer to allow for the differences in the
+ * SDR ADC and Sound card ADC sampling rates */
+#define PLAYBACK_BUF_LEN	8192
+extern short **playback_buf;
+extern int   sound_buf_num;
+extern int   demod_buf_num;
 
 /*------------------------------------------------------------------------*/
 
