@@ -17,12 +17,16 @@
 
 #include <alsa/asoundlib.h>
 #include "common.h"
-#include "dft.h"
 
-#define READI_FRAMES	512	 /* Number of frames to read from dsp */
-#define PERIOD_SIZE		4096 /* Period size of dsp in frames */
-#define NUM_PERIODS		4	 /* Number of periods */
-#define EXACT_VAL		0	 /* Set excat value of hwparams */
+#define SND_PERIOD_SIZE		4096 /* PCM period size */
+#define SND_BUF_STRIDE		8192 /* Sound buffer stride. Must be 2 * PERIOD_SIZE */
+#define SND_READI_FRAMES	512	 /* Number of frames to read from dsp */
+#define SND_NUM_PERIODS		4	 /* Number of periods */
+#define SND_EXACT_VAL		0	 /* Set excat value of hwparams */
+#define SND_NUM_CHANNELS	2	 /* 1 = MONO, 2 = STEREO <- only accepted */
+#define SND_OPEN_CAPTURE	1	 /* Open PCM device for capture  */
+#define SND_OPEN_PLAYBACK	2	 /* Open PCM device for playback */
+#define PLAYBACK_BUFFS		4	 /* Number of playback buffers */
 
 #endif
 
