@@ -61,14 +61,19 @@ Toggle_Flag( int flag )
  *
  *  Cleans up before quitting
  */
-
   void
 Cleanup( void )
 {
+#ifdef HAVE_LIBPERSEUS_SDR
+  if( rc_data.receiver_type == PERSEUS )
+	Perseus_Close_Device();
+  else
+#endif
+	Close_Tcvr_Serial();
+
   /* Release sound card */
-  Close_Capture_Handle();
+  Close_PCM_Handle();
   Close_Mixer_Handle();
-  Close_Tcvr_Serial();
 } /* Cleanup( void ) */
 
 /*------------------------------------------------------------------------*/
@@ -81,12 +86,14 @@ gboolean mem_alloc( void **ptr, size_t req )
   *ptr = malloc( req );
   if( *ptr == NULL )
   {
-	perror( "xfhell: alloc():" );
-	Error_Dialog( _("A memory allocation failed\n"\
+	perror( "xdemorse: alloc():" );
+	Error_Dialog(
+		_("A memory allocation failed\n"\
 		  "Please quit xdemorse and correct")  );
 	return( FALSE );
   }
   memset( *ptr, 0, req );
+
   return( TRUE );
 } /* End of void mem_alloc() */
 
@@ -97,11 +104,13 @@ gboolean mem_realloc( void **ptr, size_t req )
   *ptr = realloc( *ptr, req );
   if( *ptr == NULL )
   {
-	perror( "xfhell: realloc():" );
-	Error_Dialog( _("A memory re-allocation failed\n"\
+	perror( "xdemorse: realloc():" );
+	Error_Dialog(
+		_("A memory re-allocation failed\n"\
 		  "Please quit xdemorse and correct") );
 	return( FALSE );
   }
+
   return( TRUE );
 } /* End of void mem_realloc() */
 
@@ -388,10 +397,6 @@ Load_Config( gpointer data )
   else
 	rc_data.use_chnl = 1;
 
-  /* Set number of channels */
-  if( strstr(line, "MONO") ) rc_data.num_chnl = 1;
-  else rc_data.num_chnl = 2;
-
   /* Read capture source, abort if EOF */
   if( Load_Line(line, xdemorserc, _("Capture Source")) != SUCCESS )
 	return( FALSE );
@@ -461,24 +466,48 @@ Load_Config( gpointer data )
   if( Load_Line(line, xdemorserc, _("Transceiver type for CAT")) != SUCCESS )
 	return( FALSE );
   if( strcmp(line, "FT847") == 0 )
-	rc_data.tcvr_type = FT847;
+	rc_data.receiver_type = FT847;
   else if( strcmp(line, "FT857") == 0 )
-	rc_data.tcvr_type = FT857;
+	rc_data.receiver_type = FT857;
   else if( strcmp(line, "K2") == 0 )
-	rc_data.tcvr_type = K2;
+	rc_data.receiver_type = K2;
   else if( strcmp(line, "K3") == 0 )
-	rc_data.tcvr_type = K3;
+	rc_data.receiver_type = K3;
+#ifdef HAVE_LIBPERSEUS_SDR
+  else if( strcmp(line, "PERSEUS") == 0 )
+	rc_data.receiver_type = PERSEUS;
+#endif
   else if( strcmp(line, "NONE") == 0 )
-	rc_data.tcvr_type = NONE;
+	rc_data.receiver_type = NONE;
   else
   {
-	rc_data.tcvr_type = NONE;
+	rc_data.receiver_type = NONE;
 	fclose( xdemorserc );
 	Error_Dialog(
 		_("Error reading Transceiver type\n"\
 		  "Quit and correct xdemorserc") );
 	return( FALSE );
   }
+  gtk_combo_box_set_active( GTK_COMBO_BOX(receiver_combobox), rc_data.receiver_type );
+  if( rc_data.receiver_type == PERSEUS )
+	rc_data.open_type = SND_OPEN_PLAYBACK;
+  else
+	rc_data.open_type = SND_OPEN_CAPTURE;
+
+  /* Read frequency correction factor */
+  if( Load_Line(line, xdemorserc, _("Frequency Correction Factor")) != SUCCESS )
+	return( FALSE );
+  rc_data.freq_correction = atof( line );
+  if( fabs(rc_data.freq_correction) > 100.0 )
+  {
+	fclose( xdemorserc );
+	Error_Dialog(
+		_("Error reading Frequency Correction Factor\n"\
+		  "Frequency Correction Factor seems excessive\n"\
+		  "Quit and correct xdemorserc") );
+	return( FALSE );
+  }
+  rc_data.freq_correction /= 1.0E6;
 
   /* Read input tone (Rx BFO) frequency */
   if( Load_Line(line, xdemorserc, _("Input Tone")) != SUCCESS )
@@ -509,13 +538,13 @@ Load_Config( gpointer data )
   rc_data.center_line = wfall_width / 2 + 1;
 
   /* Enable Transceiver CAT */
-  if( rc_data.tcvr_type == NONE )
+  if( rc_data.receiver_type == NONE )
 	Clear_Flag( ENABLE_CAT );
   else
 	Set_Flag( ENABLE_CAT );
 
   /* Allocate memory to recv samples buffer */
-  samples_buffer.buffer_size = READI_FRAMES * rc_data.num_chnl;
+  samples_buffer.buffer_size = SND_READI_FRAMES * SND_NUM_CHANNELS;
   samples_buffer.buffer_idx  = samples_buffer.buffer_size;
   samples_buffer.buffer = NULL;
   if( !mem_alloc( (void **)&(samples_buffer.buffer),
@@ -527,7 +556,7 @@ Load_Config( gpointer data )
   memset( samples_buffer.buffer, 0,
 	  (size_t)samples_buffer.buffer_size * sizeof(short) );
 
-  Set_Flag( RCCONFIG_OK | CENTERLINE );
+  Set_Flag( RCCONFIG_OK );
   if( Initialize_Detector() )
 	Set_Flag( ENABLE_RECEIVE );
 
@@ -537,6 +566,10 @@ Load_Config( gpointer data )
 
 /*------------------------------------------------------------------*/
 
+/* Waterfall_Configure_Event()
+ *
+ * Handles the "configure" event on the waterfall
+ */
   void
 Waterfall_Configure_Event( int width, int height )
 {
@@ -565,19 +598,27 @@ Waterfall_Configure_Event( int width, int height )
   gdk_pixbuf_fill( wfall_pixbuf, 0 );
 
   /* Allocate average bin value buffer */
-  if( !mem_realloc((void **)&bin_ave,
-		(size_t)wfall_width * sizeof(int)) )
+  if( !mem_realloc((void **)&bin_ave, (size_t)wfall_width * sizeof(int)) )
 	return;
   for( idx = 0; idx < wfall_width; idx++ )
 	bin_ave[idx] = 0;
 
-  /* Puts the tone freq in middle of waterfall */
-  idx = (2 * DFT_INPUT_SIZE) / wfall_width;
+  /* Initialize ifft. The waterfall width has to be odd
+   * to provide a center line and the FFT width has to
+   * be a power of 2 so we compensate by adding 1 */
+  if( !Initialize_IFFT((int16_t)wfall_width + 1) )
+	return;
 
-  /* The tone freq must be rounded so that the dft_stride
+  /* Puts the tone freq in middle of waterfall */
+  idx = (2 * ifft_data_length) / wfall_width;
+
+  /* The tone freq must be rounded so that the ifft_stride
    * is an integer otherwise the waterfall is not accurate */
-  rc_data.dft_stride = rc_data.dsp_rate / rc_data.tone_freq  / idx;
-  rc_data.tone_freq  = rc_data.dsp_rate / rc_data.dft_stride / idx;
+  if( idx )
+  {
+	rc_data.ifft_stride = rc_data.dsp_rate / rc_data.tone_freq  / idx;
+	rc_data.tone_freq   = rc_data.dsp_rate / rc_data.ifft_stride / idx;
+  }
 
   /* Calculate parameters that depend on above */
   rc_data.max_unit = (60 * rc_data.tone_freq) /
@@ -586,9 +627,7 @@ Waterfall_Configure_Event( int width, int height )
   rc_data.min_unit = (60 * rc_data.tone_freq) /
 	(50 * CYCLES_PER_FRAG * rc_data.min_unit);
 
-  /* Initialize dft */
-  Idft_Init(DFT_INPUT_SIZE, wfall_width);
-}
+} /* Waterfall_Configure_Event() */
 
 /*------------------------------------------------------------------------*/
 
